// -*- mode: c++ -*-

#ifndef MIX_NAMEDNODE_H_
#define MIX_NAMEDNODE_H_

#include "Node.h"

namespace MiX{
  /**
   * OێNode̊NX
   *
   * OɊւ{IȃANZX񋟂
   */
  template <class charT,class traitsT>
  class NamedNode : virtual public Node<charT,traitsT>{
  public:
    MiX_Template_Typedef(charT,traitsT);
    typedef NamedNode<charT,traitsT> this_type;
  private:
    string_type name_;
    /**
     * Rs[RXgN^
     *
     * NCAg͂ĂяoȂB܂Rs[łȂB
     */
    NamedNode(const this_type& src){ };
  protected:
    ///RXgN^
    NamedNode(const string_type& name){ setName(name); }
  public:
    ///fXgN^
    virtual ~NamedNode()throw(){ };
    ///Oݒ肵܂
    void setName(const string_type& name){name_ = name;};
    ///O𓾂܂
    string_type getName() const{return name_;};
  };
}


#endif
